/*
//
// png.c
//
// PNG support functions
//
// Copyright (c) 1995-96 Jim Nelson.  Permission to distribute
// granted by the author.  No warranties are made on the fitness of this
// source code.
// PNG support by Bernd Dutkowski
*/

#include "htp.h"

BOOL PngFormatFound(FILE *file)
{
    BYTE header[10];

    /* move to BOF */
    if(fseek(file, 0, SEEK_SET) != 0)
    {
        DEBUG_PRINT(("unable to seek to start of PNG file"));
        return FALSE;
    }

    /* read first eight bytes, looking for PNG header*/
    if(fread(header, 1, 8, file) != 8)
    {
        DEBUG_PRINT(("could not read PNG image file header"));
        return FALSE;
    }

    /* is this a PNG file? */
    if(memcmp(header, "\x89\x50\x4E\x47\x0D\x0A\x1A\x0A", 8) == 0)
    {
        return TRUE;
    }

    /* not a PNG file */
    return FALSE;
}

DWORD MAKE_DWORD(BYTE b3,BYTE b2,BYTE b1,BYTE b0)
{
    DWORD temp;

    temp = (DWORD) b0;
    temp = temp << 8;
    temp = temp | ((DWORD) (b1) );
    temp = temp << 8;
    temp = temp | ((DWORD) (b2) );
    temp = temp << 8;
    temp = temp | ((DWORD) (b3) );

    return temp;
}

BOOL PngReadDimensions(FILE *file, WORD *height, WORD *width)
{
    BYTE b0;
    BYTE b1;
    BYTE b2;
    BYTE b3;

    /* move to the image size position in the file header */
    if(fseek(file, 16, SEEK_SET) != 0)
    {
        DEBUG_PRINT(("unable to seek to start of PNG file"));
        return FALSE;
    }

    /* read the width, byte by byte */
    /* this gets around machine endian problems while retaining the */
    /* fact that PNG uses little-endian notation */
    if(fread(&b0, 1, 1, file) != 1)
    {
        return FALSE;
    }

    if(fread(&b1, 1, 1, file) != 1)
    {
        return FALSE;
    }

    if(fread(&b2, 1, 1, file) != 1)
    {
        return FALSE;
    }

    if(fread(&b3, 1, 1, file) != 1)
    {
        return FALSE;
    }

    *width = (WORD) MAKE_DWORD(b3,b2,b1,b0);

    /* read the height, byte by byte */
    if(fread(&b0, 1, 1, file) != 1)
    {
        return FALSE;
    }

    if(fread(&b1, 1, 1, file) != 1)
    {
        return FALSE;
    }

    if(fread(&b2, 1, 1, file) != 1)
    {
        return FALSE;
    }

    if(fread(&b3, 1, 1, file) != 1)
    {
        return FALSE;
    }

    *height = (WORD) MAKE_DWORD(b3,b2,b1,b0);

    return TRUE;
}

